==> chromium-59.0.3071.35.tar.xz: chromium-59.0.3071.35/chrome/browser/resources/chromeos/login/encryption_migration.js <==
// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

/**
 * @fileoverview Polymer element for displaying encryption migration screen.
 */

/**
 * Enum for the UI states corresponding to sub steps inside migration screen.
 * These values must be kept in sync with
 * EncryptionMigrationScreenHandler::UIState in C++ code.
 * @enum {number}
 */
var EncryptionMigrationUIState = {
  INITIAL: 0,
  READY: 1,
  MIGRATING: 2,
  MIGRATION_FAILED: 3,
  NOT_ENOUGH_SPACE: 4
};

Polymer({
  is: 'encryption-migration',

  behaviors: [I18nBehavior],

  properties: {
    /**
     * Current UI state which corresponds to a sub step in migration process.
     * @type {EncryptionMigrationUIState}
     */
    uiState: {
      type: Number,
      value: 0
    },

    /**
     * Current migration progress in range [0, 1]. Negative value means that
     * the progress is unknown.
     */
    progress: {
      type: Number,
      value: -1
    },

    /**
     * Whether the current migration is resuming the previous one.
     */
    isResuming: {
      type: Boolean,
      value: false
    },

    /**
     * Battery level.
     */
    batteryPercent: {
      type: Number,
      value: 0
    },

    /**
     * True if the battery level is enough to start migration.
     */
    isEnoughBattery: {
      type: Boolean,
      value: true
    },

    /**
     * True if the device is charging.
     */
    isCharging: {
      type: Boolean,
      value: false
    },

    /**
     * True if the user already accepted the migration.
     */
    isMigrationAccepted: {
      type: Boolean,
      value: false
    },

    /**
     * Formatted string of the current available space size.
     */
    availableSpaceInString: {
      type: String,
      value: ''
    },

    /**
     * Formatted string of the necessary space size for migration.
     */
    necessarySpaceInString: {
      type: String,
      value: ''
    },
  },

  /**
   * Returns true if the migration is in initial state.
   * @param {EncryptionMigrationUIState} state Current UI state
   * @private
   */
  isInitial_: function(state) {
    return state == EncryptionMigrationUIState.INITIAL;
  },

  /**
   * Returns true if the migration is ready to start.
   * @param {EncryptionMigrationUIState} state Current UI state
   * @private
   */
  isReady_: function(state) {
    return state == EncryptionMigrationUIState.READY;
  },

  /**
   * Returns true if the migration is in progress.
   * @param {EncryptionMigrationUIState} state Current UI state
   * @private
   */
  isMigrating_: function(state) {
    return state == EncryptionMigrationUIState.MIGRATING;
  },

  /**
   * Returns true if the migration failed.
   * @param {EncryptionMigrationUIState} state Current UI state
   * @private
   */
  isMigrationFailed_: function(state) {
    return state == EncryptionMigrationUIState.MIGRATION_FAILED;
  },

  /**
   * Returns true if the available space is not enough to start migration.
   * @param {EncryptionMigrationUIState} state Current UI state
   * @private
   */
  isNotEnoughSpace_: function(state) {
    return state == EncryptionMigrationUIState.NOT_ENOUGH_SPACE;
  },

  /**
   * Returns true if the current migration progress is unknown.
   * @param {number} progress
   * @private
   */
  isProgressIndeterminate_: function(progress) {
    return progress < 0;
  },

  /**
   * Computes the label shown under progress bar.
   * @param {number} progress
   * @return {string}
   * @private
   */
  computeProgressLabel_: function(progress) {
    return this.i18n('migrationProgressLabel', Math.floor(progress * 100));
  },

  /**
   * Computes the warning label when battery level is not enough.
   * @param {number} batteryPercent
   * @return {string}
   * @private
   */
  computeBatteryWarningLabel_: function(batteryPercent) {
    return this.i18n('migrationBatteryWarningLabel', batteryPercent);
  },

  /**
   * Computes the label to show the necessary battery level for migration.
   * @return {string}
   * @private
   */
  computeNecessaryBatteryLevelLabel_: function() {
    return this.i18n('migrationNecessaryBatteryLevelLabel', 30);
  },

  /**
   * Computes the label to show the current available space.
   * @param {string} availableSpaceInString
   * @return {string}
   * @private
   */
  computeAvailableSpaceLabel_: function(availableSpaceInString) {
    return this.i18n('migrationAvailableSpaceLabel', availableSpaceInString);
  },

  /**
   * Computes the label to show the necessary space to start migration.
   * @param {string} necessarySpaceInString
   * @return {string}
   * @private
   */
  computeNecessarySpaceLabel_: function(necessarySpaceInString) {
    return this.i18n('migrationNecessarySpaceLabel', necessarySpaceInString);
  },

  /**
   * Handles tap on UPGRADE button.
   * @private
   */
  onUpgrade_: function() {
    this.isMigrationAccepted = true;
    this.fire('upgrade');
  },

  /**
   * Handles tap on SKIP button.
   * @private
   */
  onSkip_: function() {
    this.fire('skip');
  },

  /**
   * Handles tap on RESTART button.
   * @private
   */
  onRestart_: function() {
    this.fire('restart');
  },
});

==> chromium-59.0.3071.83.tar.xz: chromium-59.0.3071.83/chrome/browser/resources/chromeos/login/encryption_migration.js <==
// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

/**
 * @fileoverview Polymer element for displaying encryption migration screen.
 */

/**
 * Enum for the UI states corresponding to sub steps inside migration screen.
 * These values must be kept in sync with
 * EncryptionMigrationScreenHandler::UIState in C++ code.
 * @enum {number}
 */
var EncryptionMigrationUIState = {
  INITIAL: 0,
  READY: 1,
  MIGRATING: 2,
  MIGRATION_FAILED: 3,
  NOT_ENOUGH_SPACE: 4
};

Polymer({
  is: 'encryption-migration',

  behaviors: [I18nBehavior],

  properties: {
    /**
     * Current UI state which corresponds to a sub step in migration process.
     * @type {EncryptionMigrationUIState}
     */
    uiState: {
      type: Number,
      value: 0
    },

    /**
     * Current migration progress in range [0, 1]. Negative value means that
     * the progress is unknown.
     */
    progress: {
      type: Number,
      value: -1
    },

    /**
     * Whether the current migration is resuming the previous one.
     */
    isResuming: {
      type: Boolean,
      value: false
    },

    /**
     * Battery level.
     */
    batteryPercent: {
      type: Number,
      value: 0
    },

    /**
     * True if the battery level is enough to start migration.
     */
    isEnoughBattery: {
      type: Boolean,
      value: true
    },

    /**
     * True if the device is charging.
     */
    isCharging: {
      type: Boolean,
      value: false
    },

    /**
     * True if the user already accepted the migration.
     */
    isMigrationAccepted: {
      type: Boolean,
      value: false
    },

    /**
     * Formatted string of the current available space size.
     */
    availableSpaceInString: {
      type: String,
      value: ''
    },

    /**
     * Formatted string of the necessary space size for migration.
     */
    necessarySpaceInString: {
      type: String,
      value: ''
    },
  },

  /**
   * Returns true if the migration is in initial state.
   * @param {EncryptionMigrationUIState} state Current UI state
   * @private
   */
  isInitial_: function(state) {
    return state == EncryptionMigrationUIState.INITIAL;
  },

  /**
   * Returns true if the migration is ready to start.
   * @param {EncryptionMigrationUIState} state Current UI state
   * @private
   */
  isReady_: function(state) {
    return state == EncryptionMigrationUIState.READY;
  },

  /**
   * Returns true if the migration is in progress.
   * @param {EncryptionMigrationUIState} state Current UI state
   * @private
   */
  isMigrating_: function(state) {
    return state == EncryptionMigrationUIState.MIGRATING;
  },

  /**
   * Returns true if the migration failed.
   * @param {EncryptionMigrationUIState} state Current UI state
   * @private
   */
  isMigrationFailed_: function(state) {
    return state == EncryptionMigrationUIState.MIGRATION_FAILED;
  },

  /**
   * Returns true if the available space is not enough to start migration.
   * @param {EncryptionMigrationUIState} state Current UI state
   * @private
   */
  isNotEnoughSpace_: function(state) {
    return state == EncryptionMigrationUIState.NOT_ENOUGH_SPACE;
  },

  /**
   * Returns true if the current migration progress is unknown.
   * @param {number} progress
   * @private
   */
  isProgressIndeterminate_: function(progress) {
    return progress < 0;
  },

  /**
   * Computes the label shown under progress bar.
   * @param {number} progress
   * @return {string}
   * @private
   */
  computeProgressLabel_: function(progress) {
    return this.i18n('migrationProgressLabel', Math.floor(progress * 100));
  },

  /**
   * Computes the warning label when battery level is not enough.
   * @param {number} batteryPercent
   * @return {string}
   * @private
   */
  computeBatteryWarningLabel_: function(batteryPercent) {
    return this.i18n('migrationBatteryWarningLabel', batteryPercent);
  },

  /**
   * Computes the label to show the necessary battery level for migration.
   * @return {string}
   * @private
   */
  computeNecessaryBatteryLevelLabel_: function() {
    return this.i18n('migrationNecessaryBatteryLevelLabel', 30);
  },

  /**
   * Computes the label to show the current available space.
   * @param {string} availableSpaceInString
   * @return {string}
   * @private
   */
  computeAvailableSpaceLabel_: function(availableSpaceInString) {
    return this.i18n('migrationAvailableSpaceLabel', availableSpaceInString);
  },

  /**
   * Computes the label to show the necessary space to start migration.
   * @param {string} necessarySpaceInString
   * @return {string}
   * @private
   */
  computeNecessarySpaceLabel_: function(necessarySpaceInString) {
    return this.i18n('migrationNecessarySpaceLabel', necessarySpaceInString);
  },

  /**
   * Handles tap on UPGRADE button.
   * @private
   */
  onUpgrade_: function() {
    this.isMigrationAccepted = true;
    this.fire('upgrade');
  },

  /**
   * Handles tap on SKIP button.
   * @private
   */
  onSkip_: function() {
    this.fire('skip');
  },

  /**
   * Handles tap on RESTART button.
   * @private
   */
  onRestart_: function() {
    this.fire('restart');
  },

  /**
   * Handles tap on REPORT AN ISSUE button.
   * @private
   */
  onReportAnIssue_: function() {
    this.fire('openFeedbackDialog');
  },
});
